==> checkbox-bootstrap-1.5.0.tgz: package/README.md <==
<a href="http://gijgo.com/checkbox">Checkbox</a> by Gijgo.com is a plug-in for the jQuery Javascript library. It is a very fast and extandable tool, and will add advanced interaction controls to any checkbox. This plugin allows you to create checkboxes using bootstrap or material design styles. Free open source tool distributed under MIT License.

<h2>Examples</h2>


1. [Bootstrap Checkbox](http://gijgo.com/checkbox/example/bootstrap)

2. [Bootstrap 4 Checkbox](http://gijgo.com/checkbox/example/bootstrap-4)

3. [Material Design Checkbox](http://gijgo.com/checkbox/example/material-design)


<h2>Getting Started</h2>

```html
<html>
<head>
    <meta charset="utf-8" />
    <title>Checkbox example</title>
    <script src="https://code.jquery.com/jquery-3.2.1.min.js"></script>
    <script src="http://code.gijgo.com/1.5.0/js/gijgo.js" type="text/javascript"></script>
    <link href="http://code.gijgo.com/1.5.0/css/gijgo.css" rel="stylesheet" type="text/css" />
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet" type="text/css" />
</head>
<body>
    <label for="chkb-unchecked">Unchecked:</label> <input type="checkbox" id="chkb-unchecked" /> &nbsp; &nbsp;
    <label for="chkb-checked">Checked:</label> <input type="checkbox" id="chkb-checked" /> &nbsp; &nbsp;
    <label for="chkb-indeterminate">Indeterminate:</label> <input type="checkbox" id="chkb-indeterminate" /> &nbsp; &nbsp;
    <label for="chkb-disabled">Disabled:</label> <input type="checkbox" id="chkb-disabled" />
    <script>
        $('#chkb-unchecked').checkbox();
        $('#chkb-checked').checkbox().state('checked');
        $('#chkb-indeterminate').checkbox().state('indeterminate');
        $('#chkb-disabled').checkbox().state('checked').prop('disabled', true);
    </script>
</body>
</html>
```

==> checkbox-bootstrap-1.6.1.tgz: package/README.md <==
<a href="http://gijgo.com/checkbox">Checkbox</a> by Gijgo.com is a plug-in for the jQuery Javascript library. It is a very fast and extandable tool, and will add advanced interaction controls to any checkbox. This plugin allows you to create checkboxes using bootstrap or material design styles. Free open source tool distributed under MIT License.

<h2>Examples</h2>


1. [Bootstrap Checkbox](http://gijgo.com/checkbox/example/bootstrap)

2. [Bootstrap 4 Checkbox](http://gijgo.com/checkbox/example/bootstrap-4)

3. [Material Design Checkbox](http://gijgo.com/checkbox/example/material-design)


<h2>Getting Started</h2>

```html
<html>
<head>
    <meta charset="utf-8" />
    <title>Checkbox example</title>
    <script src="https://code.jquery.com/jquery-3.2.1.min.js"></script>
    <script src="/js/core.js" type="text/javascript"></script>
    <script src="/js/checkbox.js"></script>
    <link href="/css/core.css" rel="stylesheet" type="text/css">
    <link href="/css/checkbox.css" rel="stylesheet" type="text/css">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet" type="text/css" />
</head>
<body>
    <label for="chkb-unchecked">Unchecked:</label> <input type="checkbox" id="chkb-unchecked" /> &nbsp; &nbsp;
    <label for="chkb-checked">Checked:</label> <input type="checkbox" id="chkb-checked" /> &nbsp; &nbsp;
    <label for="chkb-indeterminate">Indeterminate:</label> <input type="checkbox" id="chkb-indeterminate" /> &nbsp; &nbsp;
    <label for="chkb-disabled">Disabled:</label> <input type="checkbox" id="chkb-disabled" />
    <script>
        $('#chkb-unchecked').checkbox();
        $('#chkb-checked').checkbox().state('checked');
        $('#chkb-indeterminate').checkbox().state('indeterminate');
        $('#chkb-disabled').checkbox().state('checked').prop('disabled', true);
    </script>
</body>
</html>
```
